<?php

defined('BASEPATH') OR exit('No direct script access allowed');

class Categories extends CC_Controller {
    /* #********************************************#
      #                   ClusterCoding             #
      #*********************************************#
      #      Author:     ClusterCoding              #
      #      Email:      info@clustercoding.com     #
      #      Website:    http://clustercoding.com   #
      #                                             #
      #      Version:    1.0.0                      #
      #      Copyright:  (c) 2017 - ClusterCoding   #
      #                                             #
      #*********************************************# */

    public function __construct() {
        parent::__construct();
        // Check Login Status
        $this->user_login_authentication();
        // Load Model
        $this->load->model('admin_models/directory_models/categories_model', 'cat_mdl');
    }

    public function index() {
        $data = array();
        $data['title'] = 'Manage Categories';
        $data['active_menu'] = 'category';
        $data['active_sub_menu'] = 'categories';
        $data['active_sub_sub_menu'] = '';
        $data['categories_info'] = $this->cat_mdl->get_categories_info();
        $data['main_menu'] = $this->load->view('admin_views/main_menu_v', $data, TRUE);
        $data['main_content'] = $this->load->view('admin_views/directory/categories/manage_categories_v', $data, TRUE);
        $this->load->view('admin_views/admin_master_v', $data);
    }

    public function add_category() {
        $data = array();
        $data['title'] = 'Add Category';
        $data['active_menu'] = 'category';
        $data['active_sub_menu'] = 'categories';
        $data['active_sub_sub_menu'] = '';
        $data['main_menu'] = $this->load->view('admin_views/main_menu_v', $data, TRUE);
        $data['main_content'] = $this->load->view('admin_views/directory/categories/add_category_v', $data, TRUE);
        $this->load->view('admin_views/admin_master_v', $data);
    }

    public function create_category() {
        $config = array(
            array(
                'field' => 'category_name',
                'label' => 'category name',
                'rules' => 'trim|required|max_length[250]'
            ),
            array(
                'field' => 'description',
                'label' => 'category description',
                'rules' => 'trim|required|max_length[250]'
            ),
            array(
                'field' => 'icon_name',
                'label' => 'icon name',
                'rules' => 'trim|required|max_length[50]'
            ),
            array(
                'field' => 'color_name',
                'label' => 'color name',
                'rules' => 'trim|required'
            ),
            array(
                'field' => 'publication_status',
                'label' => 'publication status',
                'rules' => 'trim|required'
            )
        );
        $this->form_validation->set_rules($config);
        if ($this->form_validation->run() == FALSE) {
            $this->add_category();
        } else {
            $data['category_name'] = $this->input->post('category_name', TRUE);
            $data['description'] = $this->input->post('description', TRUE);
            $data['icon_name'] = $this->input->post('icon_name', TRUE);
            $data['color_name'] = $this->input->post('color_name', TRUE);
            $data['publication_status'] = $this->input->post('publication_status', TRUE);
            $data['user_id'] = $this->session->userdata('admin_id');
            $data['date_added'] = date('Y-m-d H:i:s');

            $insert_id = $this->cat_mdl->store_category($data);
            if (!empty($insert_id)) {
                $sdata['success'] = 'Add successfully . ';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            } else {
                $sdata['exception'] = 'Operation failed !';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            }
        }
    }

    public function published_category($category_id) {
        $category_info = $this->cat_mdl->get_category_by_category_id($category_id);
        if (!empty($category_info)) {
            $result = $this->cat_mdl->published_category_by_id($category_id);
            if (!empty($result)) {
                $sdata['success'] = 'Published successfully .';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            } else {
                $sdata['exception'] = 'Operation failed !';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            }
        } else {
            $sdata['exception'] = 'Content not found !';
            $this->session->set_userdata($sdata);
            redirect('directory/categories', 'refresh');
        }
    }

    public function unpublished_category($category_id) {
        $category_info = $this->cat_mdl->get_category_by_category_id($category_id);
        if (!empty($category_info)) {
            $result = $this->cat_mdl->unpublished_category_by_id($category_id);
            if (!empty($result)) {
                $sdata['success'] = 'Unublished successfully .';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            } else {
                $sdata['exception'] = 'Operation failed !';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            }
        } else {
            $sdata['exception'] = 'Content not found !';
            $this->session->set_userdata($sdata);
            redirect('directory/categories', 'refresh');
        }
    }

    public function edit_category($category_id) {
        $data = array();
        $data['category_info'] = $this->cat_mdl->get_category_by_category_id($category_id);
        if (!empty($data['category_info'])) {
            $data['title'] = 'Edit Category';
            $data['active_menu'] = 'category';
            $data['active_sub_menu'] = 'categories';
            $data['active_sub_sub_menu'] = '';
            $data['main_menu'] = $this->load->view('admin_views/main_menu_v', $data, TRUE);
            $data['main_content'] = $this->load->view('admin_views/directory/categories/edit_category_v', $data, TRUE);
            $this->load->view('admin_views/admin_master_v', $data);
        } else {
            $sdata['exception'] = 'Content not found !';
            $this->session->set_userdata($sdata);
            redirect('directory/categories', 'refresh');
        }
    }

    public function update_category($category_id) {
        $category_info = $this->cat_mdl->get_category_by_category_id($category_id);
        if (!empty($category_info)) {
            $config = array(
                array(
                    'field' => 'category_name',
                    'label' => 'category name',
                    'rules' => 'trim|required|max_length[100]'
                ),
                array(
                    'field' => 'description',
                    'label' => 'description',
                    'rules' => 'trim|required|max_length[250]'
                ),
                array(
                    'field' => 'icon_name',
                    'label' => 'icon name',
                    'rules' => 'trim|required|max_length[50]'
                ),
                array(
                    'field' => 'color_name',
                    'label' => 'color name',
                    'rules' => 'trim|required'
                ),
                array(
                    'field' => 'publication_status',
                    'label' => 'publication status',
                    'rules' => 'trim|required'
                )
            );
            $this->form_validation->set_rules($config);
            if ($this->form_validation->run() == FALSE) {
                $this->edit_category($category_id);
            } else {
                $data['category_name'] = $this->input->post('category_name', TRUE);
                $data['description'] = $this->input->post('description', TRUE);
                $data['icon_name'] = $this->input->post('icon_name', TRUE);
                $data['color_name'] = $this->input->post('color_name', TRUE);
                $data['publication_status'] = $this->input->post('publication_status', TRUE);
                $data['last_updated'] = date('Y-m-d H:i:s');

                $result = $this->cat_mdl->update_category($category_id, $data);
                if (!empty($result)) {
                    $sdata['success'] = 'Update successfully .';
                    $this->session->set_userdata($sdata);
                    redirect('directory/categories', 'refresh');
                } else {
                    $sdata['exception'] = 'Operation failed !';
                    $this->session->set_userdata($sdata);
                    redirect('directory/categories', 'refresh');
                }
            }
        } else {
            $sdata['exception'] = 'Content not found !';
            $this->session->set_userdata($sdata);
            redirect('directory/categories', 'refresh');
        }
    }

    public function remove_category($category_id) {
        $category_info = $this->cat_mdl->get_category_by_category_id($category_id);
        if (!empty($category_info)) {
            $result = $this->cat_mdl->remove_category_by_id($category_id);
            if (!empty($result)) {
                $sdata['success'] = 'Remove successfully .';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            } else {
                $sdata['exception'] = 'Operation failed !';
                $this->session->set_userdata($sdata);
                redirect('directory/categories', 'refresh');
            }
        } else {
            $sdata['exception'] = 'Content not found !';
            $this->session->set_userdata($sdata);
            redirect('directory/categories', 'refresh');
        }
    }

}
